@@ -21,7 +21,7 @@
 # with this program; if not, write to the Free Software Foundation, Inc.,
 # 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 
-__version__ = "1.8.18"
+__version__ = "1.8.19"
 
 __all__ = [
 
@@ -97,7 +97,7 @@ class MalformedUrl(Exception):
 #######################################################################
 
 def plain(*args):
-    bb.msg.warn(''.join(args))
+    bb.msg.plain(''.join(args))
 
 def debug(lvl, *args):
     bb.msg.debug(lvl, None, ''.join(args))
@@ -106,7 +106,7 @@ def note(*args):
     bb.msg.note(1, None, ''.join(args))
 
 def warn(*args):
-    bb.msg.warn(1, None, ''.join(args))
+    bb.msg.warn(None, ''.join(args))
 
 def error(*args):
     bb.msg.error(None, ''.join(args))
