@@ -276,7 +276,7 @@ class BitBakeShellCommands:
         print "SHELL: Parsing '%s'" % bbfile
         parse.update_mtime( bbfile )
         cooker.bb_cache.cacheValidUpdate(bbfile)
-        fromCache = cooker.bb_cache.loadData(bbfile, cooker.configuration.data)
+        fromCache = cooker.bb_cache.loadData(bbfile, cooker.configuration.data, cooker.status)
         cooker.bb_cache.sync()
         if False: #fromCache:
             print "SHELL: File has not been updated, not reparsing"
@@ -518,7 +518,7 @@ SRC_URI = ""
 
     def stage( self, params ):
         """Execute 'stage' on a providee"""
-        self.build( params, "stage" )
+        self.build( params, "populate_staging" )
     stage.usage = "<providee>"
 
     def status( self, params ):
